package org.jboss.as.integration.hornetq.deployers.pojo;

import java.util.Map;
import java.util.Set;

import org.hornetq.api.core.SimpleString;
import org.hornetq.core.config.Configuration;
import org.hornetq.core.config.CoreQueueConfiguration;
import org.hornetq.core.security.Role;
import org.hornetq.core.server.HornetQServer;
import org.hornetq.core.settings.impl.AddressSettings;
import org.jboss.as.integration.hornetq.deployers.HornetQJMSRealDeployer;
import org.jboss.beans.metadata.api.annotations.Start;
import org.jboss.beans.metadata.api.annotations.Stop;
import org.jboss.logging.Logger;

/**
 * 
 * Objects of this class are created by the MicroContainer through
 * BeanMetadataClass at {@link HornetQCoreRealDeployer}
 * 
 * @see HornetQJMSRealDeployer
 * */
public class HornetQCoreDeployment
{

   private static final Logger log = Logger.getLogger(HornetQCoreDeployment.class);

   private HornetQServer server;

   private String name;

   private Configuration config;

   public Configuration getJmsConfig()
   {
      return config;
   }

   public void setConfig(Configuration config)
   {
      this.config = config;
   }

   public HornetQServer getServer()
   {
      return server;
   }

   public void setServer(HornetQServer server)
   {
      this.server = server;
   }

   public void setName(String name)
   {
      this.name = name;
   }

   public String getName()
   {
      return name;
   }

   @Start
   public void start()
   {
      if (log.isTraceEnabled())
      {
         log.trace(this.name + " is being started");
      }

      for (Map.Entry<String, AddressSettings> entry : config.getAddressesSettings().entrySet())
      {
         server.getAddressSettingsRepository().addMatch(entry.getKey(), entry.getValue());
      }

      for (Map.Entry<String, Set<Role>> entry : config.getSecurityRoles().entrySet())
      {
         server.getSecurityRepository().addMatch(entry.getKey(), entry.getValue());
      }

      for (CoreQueueConfiguration coreQueue : config.getQueueConfigurations())
      {
         try
         {
            server.createQueue(new SimpleString(coreQueue.getAddress()), new SimpleString(coreQueue.getName()), new SimpleString(
                  coreQueue.getFilterString()), coreQueue.isDurable(), false);
         }
         catch (Exception e)
         {
            log.warn("Error on creating queue " + coreQueue.getName() + " address = " + coreQueue.getAddress(), e);
         }
      }
   }

   @Stop
   public void stop()
   {
      if (log.isTraceEnabled())
      {
         log.trace(this.name + " is being stopped");
      }

      for (String entry : config.getAddressesSettings().keySet())
      {
         server.getAddressSettingsRepository().removeMatch(entry);
      }

      for (String entry : config.getSecurityRoles().keySet())
      {
         server.getSecurityRepository().removeMatch(entry);
      }
      
      
      // Undeploy core queues means nothing on core queues, so no need to do anything here
   }

}
